MatLiveAudioRoomLayoutConfig class
Constructors
-
MatLiveAudioRoomLayoutConfig({double rowSpacing = 0, List<
MatLiveAudioRoomLayoutRowConfig> ? rowConfigs})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rowConfigs
↔ List<
MatLiveAudioRoomLayoutRowConfig> -
Configuration of each row
getter/setter pair
- rowSpacing → double
-
The spacing between rows, in pixels
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited