LiveKitService class

Constructors

LiveKitService({required String baseUrl})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createToken({required String username, required String roomId}) Future<TokenInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRoomMetadata({required String roomId, required String metadata}) Future<Map<String, dynamic>>

Operators

operator ==(Object other) bool
The equality operator.
inherited