MatLiveEvents class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- addNewSeats → const int
- clearChat → const int
- inviteUserToTakeMic → const int
- isMicOpened → const int
- kickOutUser → const int
- leaveSeat → const int
- lockSeat → const int
- muteSeat → const int
- removeSeats → const int
- removeUserFromSeat → const int
- requestTakeMic → const int
- sendGift → const int
- sendMessage → const int
- switchSeat → const int
- takeSeat → const int
- unMuteSeat → const int