MatLiveUser class
Constructors
Properties
- avatar ↔ String
-
getter/setter pair
-
avatarUrlNotifier
↔ ValueNotifier<
String?> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isCamerOnNotifier
↔ ValueNotifier<
bool> -
getter/setter pair
-
isMicOnNotifier
↔ ValueNotifier<
bool> -
getter/setter pair
- metadata ↔ String?
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- roomId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamID ↔ String?
-
getter/setter pair
- userId ↔ String
-
getter/setter pair
-
videoViewNotifier
↔ ValueNotifier<
Widget?> -
getter/setter pair
- viewID ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited